'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

const index = require('./index-c4489226.js');

class Parser {
    static Parse(xmlstr) {
        if (typeof DOMParser !== 'undefined') {
            let domDoc = (new DOMParser()).parseFromString(xmlstr, 'application/xml');
            // let's check for errors
            if (domDoc.documentElement.nodeName == "parsererror") {
                throw new Error('XML parsing error');
            }
            return domDoc;
        }
        return null;
    }
}

const xmlViewerComponentCss = "code{margin:.1rem .25rem 1rem .25rem;padding:0;color:#767676;font-family:monospace, monospace;text-shadow:0 1px #fff;direction:ltr;text-align:left;word-spacing:normal;word-break:normal;word-wrap:normal;line-height:1.2;-moz-tab-size:2;-o-tab-size:2;tab-size:2;-webkit-hyphens:none;-moz-hyphens:none;-ms-hyphens:none;hyphens:none}code ul{list-style-type:none;margin:0;padding-left:1rem}code div.element{font-weight:bold;color:darkred;display:inline-block}code div.element-content{font-weight:normal;display:inline-block}code span.attr{font-weight:bold;color:#535353}code span.attr-value{font-weight:normal}code div.comment{color:darkgreen}";

const XmlViewerComponent = class {
    constructor(hostRef) {
        index.registerInstance(this, hostRef);
    }
    componentDidLoad() {
    }
    get Xml() {
        return this.xml;
    }
    set Xml(xml) {
        this.xml = xml;
    }
    // for FireFox and maybe Edge.
    toArray(obj) {
        let arr = [];
        for (let i = 0; i < obj.length; i++) {
            arr.push(obj[i]);
        }
        return arr;
    }
    prepareXml() {
        let xdoc = Parser.Parse(this.xml.trim());
        return xdoc;
    }
    renderAttribute(attribute) {
        return (index.h("span", null, "\u00A0", index.h("span", { class: "attr" }, attribute.name, "=\"", index.h("span", { class: "attr-value" }, attribute.value), "\"")));
    }
    renderNodeValue(nodeValue) {
        if (!nodeValue) {
            return null;
        }
        const val = unescape(nodeValue.trim());
        if (val.length === 0) {
            return null;
        }
        if (val.length > 150) {
            return (index.h("ul", null, index.h("li", null, val)));
        }
        return (index.h("span", null, val));
    }
    renderComment(comment) {
        if (!comment) {
            return null;
        }
        return (index.h("div", { class: "comment" }, "<--\u00A0", comment.nodeValue.trim(), "\u00A0-->"));
    }
    renderCData(node) {
        if (!node) {
            return null;
        }
        const data = unescape(`<![CDATA[${node.textContent.trim()}]]>`);
        return (index.h("ul", null, index.h("li", null, index.h("div", null, data))));
    }
    renderNode(node) {
        if (!node) {
            return null;
        }
        if (node.nodeName === "#comment") {
            return this.renderComment(node);
        }
        if (node.nodeName === `#cdata-section`) {
            return this.renderCData(node);
        }
        return null;
    }
    // rendering node. This function calls to itself in recursion way in case of child nodes
    renderElement(element) {
        if (!element) {
            return null;
        }
        if (element.nodeName === "#comment") {
            return (index.h("span", null, "comment"));
        }
        // element.attributes, childNodes and children has no iterator so I have to turn it into an array
        const attributes = this.toArray(element.attributes);
        const childNodes = this.toArray(element.childNodes);
        const children = this.toArray(element.children);
        let nodeValue = element.firstChild ? element.firstChild.nodeValue : null;
        nodeValue = nodeValue ? nodeValue.trim() : null;
        return (index.h("ul", null, index.h("li", null, index.h("div", { class: "element" }, "<", element.nodeName, attributes.map(a => this.renderAttribute(a)), ">"), index.h("div", { class: "element-content" }, this.renderNodeValue(nodeValue)), children.map(c => this.renderElement(c)), childNodes.map(c => this.renderNode(c)), index.h("div", { class: "element" }, "</", element.nodeName, ">"))));
    }
    render() {
        if (this.xml === null || this.xml === undefined) {
            return null;
        }
        if (this.xml.length === 0) {
            return null;
        }
        let xdoc = null;
        try {
            xdoc = this.prepareXml();
        }
        catch (e) {
            console.error(e);
        }
        if (!xdoc || !xdoc.documentElement.childNodes) {
            return (index.h("code", null, this.xml));
        }
        return (index.h("p", null, index.h("code", null, this.renderElement(xdoc.documentElement))));
    }
};
XmlViewerComponent.style = xmlViewerComponentCss;

exports.xml_viewer_component = XmlViewerComponent;
